@@ -1,11 +1,5 @@
 package MooseX::Declare::StackItem;
-{
-  $MooseX::Declare::StackItem::VERSION = '0.38';
-}
-BEGIN {
-  $MooseX::Declare::StackItem::AUTHORITY = 'cpan:FLORA';
-}
-
+$MooseX::Declare::StackItem::VERSION = '0.39';
 use Moose;
 
 use namespace::clean -except => 'meta';
@@ -60,26 +54,3 @@ sub serialize {
 __PACKAGE__->meta->make_immutable;
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-MooseX::Declare::StackItem
-
-=head1 AUTHOR
-
-Florian Ragwitz <rafl@debian.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by Florian Ragwitz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
