@@ -1,12 +1,6 @@
 package MooseX::Declare::Syntax::MooseSetup;
-{
-  $MooseX::Declare::Syntax::MooseSetup::VERSION = '0.38';
-}
-BEGIN {
-  $MooseX::Declare::Syntax::MooseSetup::AUTHORITY = 'cpan:FLORA';
-}
 # ABSTRACT: Common Moose namespaces declarations
-
+$MooseX::Declare::Syntax::MooseSetup::VERSION = '0.39';
 use Moose::Role;
 
 use Moose::Util  qw( find_meta );
@@ -19,21 +13,89 @@ use aliased 'MooseX::Declare::Syntax::Keyword::Clean', 'CleanKeyword';
 
 use namespace::clean -except => 'meta';
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This role is basically an extension to
+#pod L<NamespaceHandling|MooseX::Declare::Syntax::NamespaceHandling>. It adds all
+#pod the common parts for L<Moose> namespace definitions. Examples of this role
+#pod can be found in the L<class|MooseX::Declare::Syntax::Keyword::Class> and
+#pod L<role|MooseX::Declare::Syntax::Keyword::Role> keywords.
+#pod
+#pod =head1 CONSUMES
+#pod
+#pod =for :list
+#pod * L<MooseX::Declare::Syntax::NamespaceHandling>
+#pod * L<MooseX::Declare::Syntax::EmptyBlockIfMissing>
+#pod
+#pod =cut
 
 with qw(
     MooseX::Declare::Syntax::NamespaceHandling
     MooseX::Declare::Syntax::EmptyBlockIfMissing
 );
 
+#pod =method auto_make_immutable
+#pod
+#pod   Bool Object->auto_make_immutable ()
+#pod
+#pod Since L<Moose::Role>s can't be made immutable (this is not a bug or a
+#pod missing feature, it would make no sense), this always returns false.
+#pod
+#pod =cut
 
 sub auto_make_immutable { 0 }
 
+#pod =method imported_moose_symbols
+#pod
+#pod   List Object->imported_moose_symbols ()
+#pod
+#pod This will return C<confess> and C<blessed> by default to provide as
+#pod additional imports to the namespace.
+#pod
+#pod =cut
 
 sub imported_moose_symbols { qw( confess blessed ) }
 
+#pod =method import_symbols_from
+#pod
+#pod   Str Object->import_symbols_from ()
+#pod
+#pod The namespace from which the additional imports will be imported. This
+#pod will return C<Moose> by default.
+#pod
+#pod =cut
 
 sub import_symbols_from { 'Moose' }
 
+#pod =head1 MODIFIED METHODS
+#pod
+#pod =head2 default_inner
+#pod
+#pod   ArrayRef default_inner ()
+#pod
+#pod This will provide the following default inner-handlers to the namspace:
+#pod
+#pod =for :list
+#pod * method
+#pod A simple L<Method|MooseX::Declare::Syntax::Keyword::Method> handler.
+#pod * around
+#pod This is a L<MethodModifier|MooseX::Declare::Syntax::Keyword::MethodModifier>
+#pod handler that will start the signature of the generated method with
+#pod C<$orig: $self> to provide the original method in C<$orig>.
+#pod * after
+#pod * before
+#pod * override
+#pod * augment
+#pod These four handlers are L<MethodModifier|MooseX::Declare::Syntax::Keyword::MethodModifier>
+#pod instances.
+#pod * clean
+#pod This is an instance of the L<Clean|MooseX::Declare::Syntax::Keyword::Clean> keyword
+#pod handler.
+#pod
+#pod The original method will never be called and all arguments are ignored at the
+#pod moment.
+#pod
+#pod =cut
 
 around default_inner => sub {
     return [
@@ -52,6 +114,14 @@ around default_inner => sub {
     ];
 };
 
+#pod =head2 setup_inner_for
+#pod
+#pod   Object->setup_inner_for (ClassName $class)
+#pod
+#pod This will install a C<with> function that will push its arguments onto a global
+#pod storage array holding the roles of the current namespace.
+#pod
+#pod =cut
 
 after setup_inner_for => sub {
     my ($self, $setup_class, %args) = @_;
@@ -59,6 +129,20 @@ after setup_inner_for => sub {
     $keyword->setup_for($setup_class, %args);
 };
 
+#pod =head2 add_namespace_customizations
+#pod
+#pod   Object->add_namespace_customizations (Object $context, Str $package, HashRef $options)
+#pod
+#pod After all other customizations, this will first add code to import the
+#pod L</imported_moose_symbols> from the package returned in L</import_symbols_from> to
+#pod the L<preamble|MooseX::Declare::Context/preamble_code_parts>.
+#pod
+#pod Then it will add a code part that will immutabilize the class to the
+#pod L<cleanup|MooseX::Declare::Context/cleanup_code_parts> code if the
+#pod L</auto_make_immutable> method returned a true value and C<< $options->{is}{mutable} >>
+#pod does not exist.
+#pod
+#pod =cut
 
 after add_namespace_customizations => sub {
     my ($self, $ctx, $package) = @_;
@@ -75,6 +159,16 @@ after add_namespace_customizations => sub {
          and not exists $ctx->options->{is}{mutable};
 };
 
+#pod =head2 handle_post_parsing
+#pod
+#pod   CodeRef Object->handle_post_parsing (Object $context, Str $package, Str|Object $name)
+#pod
+#pod Generates a callback that sets up the roles in the global role storage for the current
+#pod namespace. The C<$name> parameter will be the specified name (in contrast to C<$package>
+#pod which will always be the fully qualified name) or the anonymous metaclass instance if
+#pod none was specified.
+#pod
+#pod =cut
 
 after handle_post_parsing => sub {
     my ($self, $ctx, $package, $class) = @_;
@@ -82,6 +176,13 @@ after handle_post_parsing => sub {
 };
 
 
+#pod =head1 SEE ALSO
+#pod
+#pod =for :list
+#pod * L<MooseX::Declare>
+#pod * L<Moose>
+#pod
+#pod =cut
 
 1;
 
@@ -95,6 +196,10 @@ __END__
 
 MooseX::Declare::Syntax::MooseSetup - Common Moose namespaces declarations
 
+=head1 VERSION
+
+version 0.39
+
 =head1 DESCRIPTION
 
 This role is basically an extension to
@@ -212,7 +317,7 @@ the L<preamble|MooseX::Declare::Context/preamble_code_parts>.
 
 Then it will add a code part that will immutabilize the class to the
 L<cleanup|MooseX::Declare::Context/cleanup_code_parts> code if the
-L</auto_make_immutable> method returned a true value and C<$options->{is}{mutable}>
+L</auto_make_immutable> method returned a true value and C<< $options->{is}{mutable} >>
 does not exist.
 
 =head2 handle_post_parsing
